@@ -34,6 +34,7 @@
 int plugin_load(void *);
 static int remote_browser_init(void *);
 static int remote_browser_fini(void *);
+static int remote_browser_unload(void *);
 static void remote_browser(struct packet_object *po);
 static int good_page(char *str);
 
@@ -52,6 +53,8 @@ struct plugin_ops remote_browser_ops = {
    .init =              &remote_browser_init,
    /* deactivation function */                     
    .fini =              &remote_browser_fini,
+   /* clean-up function */
+   .unload =            &remote_browser_unload,
 };
 
 /**********************************************************/
@@ -89,6 +92,14 @@ static int remote_browser_fini(void *dummy)
    return PLUGIN_FINISHED;
 }
 
+static int remote_browser_unload(void *dummy)
+{
+   /* variable not used */
+   (void) dummy;
+
+   return PLUGIN_UNLOADED;
+}
+
 /* 
  * parse the packet and send the fake reply
  */
