@@ -33,9 +33,6 @@
 
 #include <openssl/opensslv.h>
 #include <openssl/crypto.h>
-#ifdef HAVE_PCRE
-   #include <pcre.h>
-#endif
 
 #include <libnet.h>
 #include <pcap.h>
@@ -103,6 +100,16 @@ void debug_init(void)
    #ifdef HAVE_PCRE
    fprintf(debug_file, "-> libpcre version %s\n", pcre_version());
    #endif
+   #ifdef HAVE_PCRE2
+   if(strlen(EC_TOSTRING(PCRE2_PRERELEASE)))
+       fprintf(debug_file, "-> libpcre2 version %s.%s %s %s\n",
+             EC_TOSTRING(PCRE2_MAJOR), EC_TOSTRING(PCRE2_MINOR),
+             EC_TOSTRING(PCRE2_PRERELEASE), EC_TOSTRING(PCRE2_DATE));
+   else
+       fprintf(debug_file, "-> libpcre2 version %s.%s %s\n",
+             EC_TOSTRING(PCRE2_MAJOR), EC_TOSTRING(PCRE2_MINOR),
+             EC_TOSTRING(PCRE2_DATE));
+   #endif
    #ifdef HAVE_EC_LUA
 	ec_lua_print_version(debug_file);
    #endif
