@@ -83,6 +83,9 @@ void print_host(struct host_profile *h)
    struct active_user *u;
    char tmp[MAX_ASCII_ADDR_LEN];
    char os[OS_LEN+1];
+#ifdef HAVE_GEOIP
+   char country[MAX_GEOIP_STR_LEN];
+#endif
 
    memset(os, 0, sizeof(os));
    
@@ -93,7 +96,7 @@ void print_host(struct host_profile *h)
 
 #ifdef HAVE_GEOIP
    if (EC_GBL_CONF->geoip_support_enable)
-      fprintf(stdout, " Location     : %s \n", geoip_country_by_ip(&h->L3_addr));
+      fprintf(stdout, " Location     : %s \n", geoip_get_by_ip(&h->L3_addr, GEOIP_CNAME, country, MAX_GEOIP_STR_LEN));
 #endif
 
    fprintf(stdout, "\n");
@@ -161,6 +164,9 @@ void print_host_xml(struct host_profile *h)
    struct active_user *u;
    char tmp[MAX_ASCII_ADDR_LEN];
    char os[OS_LEN+1];
+#ifdef HAVE_GEOIP
+   char country[MAX_GEOIP_STR_LEN];
+#endif
 
    memset(os, 0, sizeof(os));
    
@@ -171,7 +177,7 @@ void print_host_xml(struct host_profile *h)
 #ifdef HAVE_GEOIP
    if (EC_GBL_CONF->geoip_support_enable)
       fprintf(stdout, "\t\t<location>%s</location>\n", 
-            geoip_country_by_ip(&h->L3_addr));
+            geoip_get_by_ip(&h->L3_addr, GEOIP_CNAME, country, MAX_GEOIP_STR_LEN));
 #endif
 
    if (h->type & FP_HOST_LOCAL || h->type == FP_UNKNOWN) {
