@@ -74,13 +74,18 @@ void set_reversed(void)
 
 void set_plugin(char *name)
 {
-    struct plugin_list *plugin;
+    struct plugin_list *plugin, *tmp;
 
     if(!strcasecmp(name, "list")) {
         plugin_list();
         clean_exit(0);
     }
 
+    /* check if plugin name is a duplicate */
+    LIST_FOREACH_SAFE(plugin, &EC_GBL_OPTIONS->plugins, next, tmp)
+       if (!strcmp(plugin->name, name))
+             return;
+
     SAFE_CALLOC(plugin, 1, sizeof(struct plugin_list));
     plugin->name = strdup(name);
     plugin->exists = true;
@@ -88,6 +93,24 @@ void set_plugin(char *name)
 
 }
 
+void set_plugin_list(char *list)
+{
+   char *tmp, *p, *plugin;
+
+   p = list;
+
+   while((plugin = ec_strtok(p, ",", &tmp))) {
+      if (plugin) {
+         set_plugin(plugin);
+         p = NULL;
+      }
+      else
+         break;
+   }
+
+   SAFE_FREE(list);
+}
+
 void set_proto(char *proto)
 {
 	EC_GBL_OPTIONS->proto = strdup(proto);
