@@ -47,6 +47,7 @@ static handler_t *signal_handle(int signo, handler_t *handler, int flags);
 static void signal_SEGV(int sig);
 static void signal_TERM(int sig);
 static void signal_CHLD(int sig);
+static void signal_USR1(int sig);
 
 /*************************************/
 
@@ -88,6 +89,9 @@ void signal_handler(void)
 #ifdef SIGTTIN
    signal_handle(SIGTTIN, SIG_IGN, 0);
 #endif
+#ifdef SIGUSR1
+   signal_handle(SIGUSR1, signal_USR1, 0);
+#endif
 }
 
 
@@ -151,12 +155,13 @@ static void signal_SEGV(int sig)
    fprintf (stderr, "  1) set ec_uid to 0 (so the core will be dumped)\n\n");
    fprintf (stderr, "  2) execute ettercap with \"-w debug_dump.pcap\"\n\n");
    fprintf (stderr, "  3) reproduce the critical situation\n\n");
-   fprintf (stderr, "  4) make a report : \n\t\"tar zcvf error.tar.gz %s-%s_debug.log debug_dump.pcap\"\n\n", EC_PROGRAM, EC_VERSION);
+   fprintf (stderr, "  4) make a report : \n\t\"tar zcvf error.tar.gz %s-%s_debug.log debug_dump.pcap\"\n\n", 
+         PROGRAM, EC_VERSION);
    fprintf (stderr, "  5) get the gdb backtrace :\n"
                     "  \t - \"gdb %s core\"\n"
                     "  \t - at the gdb prompt \"bt\"\n"
                     "  \t - at the gdb prompt \"quit\" and return to the shell\n"
-                    "  \t - copy and paste this output.\n\n", EC_PROGRAM);
+                    "  \t - copy and paste this output.\n\n", PROGRAM);
    fprintf (stderr, "  6) mail us the output of gdb and the error.tar.gz\n");
    fprintf (stderr, "============================================================================\n");
    
@@ -215,9 +220,9 @@ static void signal_TERM(int sig)
       fprintf(stderr, "\n\nUser requested a CTRL+C... (deprecated, next time use proper shutdown)\n\n");
    } else {
    #ifdef HAVE_STRSIGNAL
-      fprintf(stderr, "\n\n Shutting down %s (received SIGNAL: %d | %s)\n\n", GBL_PROGRAM, sig, strsignal(sig));
+      fprintf(stderr, "\n\n Shutting down %s (received SIGNAL: %d | %s)\n\n", PROGRAM, sig, strsignal(sig));
    #else
-      fprintf(stderr, "\n\n Shutting down %s (received SIGNAL: %d)\n\n", GBL_PROGRAM, sig);
+      fprintf(stderr, "\n\n Shutting down %s (received SIGNAL: %d)\n\n", PROGRAM, sig);
    #endif
    }
    
@@ -246,6 +251,14 @@ static void signal_CHLD(int sig)
 #endif
 }
 
+static void signal_USR1(int sig)
+{
+   /* variable not used */
+   (void) sig;
+
+   /* nothing to do by signal handler */
+}
+
 /* EOF */
 
 // vim:ts=3:expandtab
