@@ -71,11 +71,11 @@
 #define TLS_server_method SSLv23_server_method
 #endif
 
-#if (OPENSSL_VERSION_NUMBER >= 0x10100000L)
+#if (OPENSSL_VERSION_NUMBER >= 0x10100000L) && !defined(LIBRESSL_VERSION_NUMBER)
 #define HAVE_OPENSSL_1_1_0
 #endif
 
-#if (OPENSSL_VERSION_NUMBER >= 0x10101000L)
+#if (OPENSSL_VERSION_NUMBER >= 0x10101000L) && !defined(LIBRESSL_VERSION_NUMBER) && !defined OS_BSD_OPEN
 #define HAVE_OPENSSL_1_1_1
 #endif
 
@@ -414,13 +414,9 @@ static void sslw_hook_handled(struct packet_object *po)
 
       sslw_create_session(&s, PACKET);
 
-#ifndef OS_LINUX
       /* Remember the real destination IP */
       memcpy(s->data, &po->L3.dst, sizeof(struct ip_addr));
       session_put(s);
-#else
-      SAFE_FREE(s); /* Just get rid of it */
-#endif
    } else /* Pass only the SYN for conntrack */
       po->flags |= PO_IGNORE;
 }
@@ -508,13 +504,13 @@ static void sslw_bind_wrapper(void)
       if (ec_redirect(EC_REDIR_ACTION_INSERT, le->name,
                EC_REDIR_PROTO_IPV4, NULL,
                le->sslw_port, le->redir_port) != E_SUCCESS)
-        FATAL_ERROR("Can't insert firewall redirects");
+        FATAL_ERROR("Can't insert IPv4 firewall redirects");
 
 #ifdef WITH_IPV6
       if (ec_redirect(EC_REDIR_ACTION_INSERT, le->name,
                EC_REDIR_PROTO_IPV6, NULL,
                le->sslw_port, le->redir_port) != E_SUCCESS)
-        FATAL_ERROR("Can't insert firewall redirects");
+        FATAL_ERROR("Can't insert IPv6 firewall redirects. Considered uncommenting redir6 commands?");
 #endif
 
    }
@@ -1048,14 +1044,16 @@ static void sslw_initialize_po(struct packet_object *po, u_char *p_data)
  * Create a self-signed certificate
  */
 static X509 *sslw_create_selfsigned(X509 *server_cert)
-{   
-   X509 *out_cert;
+{
+   unsigned char *ext_bytes = NULL;
+   X509 *out_cert = NULL;
+   X509 *ret = NULL;
    X509_EXTENSION *ext;
    const EVP_MD *md;
    int index = 0;
-   
+
    if ((out_cert = X509_new()) == NULL)
-      return NULL;
+      goto err;
 
    /* Set out public key, real server name... */
    X509_set_version(out_cert, X509_get_version(server_cert));
@@ -1064,9 +1062,9 @@ static X509 *sslw_create_selfsigned(X509 *server_cert)
    X509_set_notAfter(out_cert, X509_get_notAfter(server_cert));
    X509_set_pubkey(out_cert, global_pk);
    X509_set_subject_name(out_cert, X509_get_subject_name(server_cert));
-   X509_set_issuer_name(out_cert, X509_get_issuer_name(server_cert));  
+   X509_set_issuer_name(out_cert, X509_get_issuer_name(server_cert));
 
-   /* Modify the issuer a little bit */ 
+   /* Modify the issuer a little bit */
    //X509_NAME_add_entry_by_txt(X509_get_issuer_name(out_cert), "L", MBSTRING_ASC, " ", -1, -1, 0);
 
    index = X509_get_ext_by_NID(server_cert, NID_authority_key_identifier, -1);
@@ -1074,25 +1072,35 @@ static X509 *sslw_create_selfsigned(X509 *server_cert)
       ext = X509_get_ext(server_cert, index);
 #ifdef HAVE_OPAQUE_RSA_DSA_DH
       ASN1_OCTET_STRING* os;
-      os = X509_EXTENSION_get_data (ext);
+      os = X509_EXTENSION_get_data(ext);
+      if (ASN1_STRING_length(os) < 9)
+         goto err;
+
+      SAFE_CALLOC(ext_bytes, 1, ASN1_STRING_length(os));
+      memcpy(ext_bytes, ASN1_STRING_get0_data(os), ASN1_STRING_length(os));
 #endif
       if (ext) {
 #ifdef HAVE_OPAQUE_RSA_DSA_DH
-         os->data[7] = 0xe7;
-         os->data[8] = 0x7e;
-         X509_EXTENSION_set_data (ext, os);
+         ext_bytes[7] = 0xe7;
+         ext_bytes[8] = 0x7e;
+         if (!ASN1_STRING_set(os, ext_bytes, ASN1_STRING_length(os)))
+            goto err;
+         if (!X509_EXTENSION_set_data(ext, os))
+            goto err;
 #else
          ext->value->data[7] = 0xe7;
          ext->value->data[8] = 0x7e;
 #endif
-         X509_add_ext(out_cert, ext, -1);
+         if (!X509_add_ext(out_cert, ext, -1))
+            goto err;
       }
    }
 
    /* take over SAN extension from peer certificate */
    index = X509_get_ext_by_NID(server_cert, NID_subject_alt_name, index);
    if (index >= 0) {
-      X509_add_ext(out_cert, X509_get_ext(server_cert, index), -1);
+      if (!X509_add_ext(out_cert, X509_get_ext(server_cert, index), -1))
+         goto err;
    }
 
    /* grab digest algorithm from peer certificate */
@@ -1105,12 +1113,18 @@ static X509 *sslw_create_selfsigned(X509 *server_cert)
 
    /* Self-sign our certificate */
    if (!X509_sign(out_cert, global_pk, md)) {
-      X509_free(out_cert);
       DEBUG_MSG("Error self-signing X509");
-      return NULL;
+      goto err;
    }
-     
-   return out_cert;
+
+   ret = out_cert;
+   out_cert = NULL;
+
+err:
+   SAFE_FREE(out_cert);
+   SAFE_FREE(ext_bytes);
+
+   return ret;
 }
 
 /* 
