@@ -58,11 +58,6 @@ static void wdg_input_form_destroy(struct wdg_object *wo);
 static void wdg_input_form_create(struct wdg_object *wo);
 static void wdg_input_consolidate(struct wdg_object *wo);
 
-void wdg_input_size(wdg_t *wo, size_t x, size_t y);
-void wdg_input_add(wdg_t *wo, size_t x, size_t y, const char *caption, char *buf, size_t len, size_t lines);
-void wdg_input_set_callback(wdg_t *wo, void (*callback)(void));
-void wdg_input_get_input(wdg_t *wo);
-
 /*******************************************/
 
 /* 
@@ -116,7 +111,7 @@ static int wdg_input_destroy(struct wdg_object *wo)
    
    WDG_SAFE_FREE(wo->extend);
 
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /* 
@@ -126,7 +121,7 @@ static int wdg_input_resize(struct wdg_object *wo)
 {
    wdg_input_redraw(wo);
 
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /* 
@@ -185,7 +180,7 @@ static int wdg_input_redraw(struct wdg_object *wo)
 
       /* create the menu window (fixed dimensions) */
       if ((ww->win = newwin(l, c, y, x)) == NULL)
-         return -WDG_EFATAL;
+         return -WDG_E_FATAL;
 
       /* set the window color */
       wbkgd(ww->win, COLOR_PAIR(wo->window_color));
@@ -211,7 +206,7 @@ static int wdg_input_redraw(struct wdg_object *wo)
 
    wo->flags |= WDG_OBJ_VISIBLE;
 
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /* 
@@ -225,7 +220,7 @@ static int wdg_input_get_focus(struct wdg_object *wo)
    /* redraw the window */
    wdg_input_redraw(wo);
    
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /* 
@@ -239,7 +234,7 @@ static int wdg_input_lost_focus(struct wdg_object *wo)
    /* redraw the window */
    wdg_input_redraw(wo);
    
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /* 
@@ -261,7 +256,7 @@ static int wdg_input_get_msg(struct wdg_object *wo, int key, struct wdg_mouse_ev
             /* redraw the menu */
             wdg_input_redraw(wo);
          } else {
-            return -WDG_ENOTHANDLED;
+            return -WDG_E_NOTHANDLED;
          }
          break;
       
@@ -277,12 +272,12 @@ static int wdg_input_get_msg(struct wdg_object *wo, int key, struct wdg_mouse_ev
          if (wo->flags & WDG_OBJ_FOCUSED) {
             return wdg_input_driver(wo, key, mouse);
          } else {
-            return -WDG_ENOTHANDLED;
+            return -WDG_E_NOTHANDLED;
          }
          break;
    }
    
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /*
@@ -319,7 +314,7 @@ static void wdg_input_borders(struct wdg_object *wo)
             wmove(ww->win, 0, c - strlen(wo->title) - 3);
             break;
       }
-      wprintw(ww->win, wo->title);
+      wprintw(ww->win, "%s", wo->title);
    }
    
    /* restore the attribute */
@@ -392,6 +387,9 @@ static int wdg_input_driver(struct wdg_object *wo, int key, struct wdg_mouse_eve
 {
    WDG_WO_EXT(struct wdg_input_handle, ww);
    int c, v;
+
+   /* variable currently not used */
+   (void) mouse;
    
    WDG_DEBUG_MSG("keypress driver: %d", key);
    
@@ -415,7 +413,7 @@ static int wdg_input_driver(struct wdg_object *wo, int key, struct wdg_mouse_eve
 
    wnoutrefresh(ww->fwin);
       
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /*
@@ -538,6 +536,7 @@ static void wdg_input_consolidate(struct wdg_object *wo)
    WDG_WO_EXT(struct wdg_input_handle, ww);
    char *buf;
    int i = 0, j;
+   size_t buflen;
    void (*callback)(void);
    
    WDG_DEBUG_MSG("wdg_input_consolidate");
@@ -545,9 +544,10 @@ static void wdg_input_consolidate(struct wdg_object *wo)
    while(ww->fields[i] != NULL) {
       /* get the buffer */
       buf = field_buffer(ww->fields[i+1], 0);
+      buflen = strlen(buf);
 
       /* trim out the trailing spaces */
-      for (j = strlen(buf) - 1; j >= 0; j--)
+      for (j = buflen - 1; j >= 0; j--)
          if (buf[j] == ' ')
             buf[j] = 0;
          else
