@@ -48,9 +48,6 @@ static int wdg_scroll_get_msg(struct wdg_object *wo, int key, struct wdg_mouse_e
 
 static void wdg_scroll_border(struct wdg_object *wo);
 
-void wdg_scroll_erase(wdg_t *wo);
-void wdg_scroll_print(wdg_t *wo, int color, char *fmt, ...);
-void wdg_scroll_set_lines(wdg_t *wo, size_t lines);
 static void wdg_set_scroll(struct wdg_object *wo, int s);
 static void wdg_mouse_scroll(struct wdg_object *wo, int s);
 
@@ -96,7 +93,7 @@ static int wdg_scroll_destroy(struct wdg_object *wo)
 
    WDG_SAFE_FREE(wo->extend);
 
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /* 
@@ -106,7 +103,7 @@ static int wdg_scroll_resize(struct wdg_object *wo)
 {
    wdg_scroll_redraw(wo);
 
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /* 
@@ -152,7 +149,7 @@ static int wdg_scroll_redraw(struct wdg_object *wo)
 
       /* create the outher window */
       if ((ww->win = newwin(l, c, y, x)) == NULL)
-         return -WDG_EFATAL;
+         return -WDG_E_FATAL;
 
       /* draw the borders */
       wdg_scroll_border(wo);
@@ -161,7 +158,7 @@ static int wdg_scroll_redraw(struct wdg_object *wo)
       
       /* create the inner (actual) window */
       if ((ww->sub = newpad(ww->y_max, c - 2)) == NULL)
-         return -WDG_EFATAL;
+         return -WDG_E_FATAL;
       
       /* set the window color */
       wbkgd(ww->sub, COLOR_PAIR(wo->window_color));
@@ -181,7 +178,7 @@ static int wdg_scroll_redraw(struct wdg_object *wo)
    
    wo->flags |= WDG_OBJ_VISIBLE;
 
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /* 
@@ -195,7 +192,7 @@ static int wdg_scroll_get_focus(struct wdg_object *wo)
    /* redraw the window */
    wdg_scroll_redraw(wo);
    
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /* 
@@ -209,7 +206,7 @@ static int wdg_scroll_lost_focus(struct wdg_object *wo)
    /* redraw the window */
    wdg_scroll_redraw(wo);
    
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /* 
@@ -238,7 +235,7 @@ static int wdg_scroll_get_msg(struct wdg_object *wo, int key, struct wdg_mouse_e
                wnoutrefresh(ww->win);
             }
          } else 
-            return -WDG_ENOTHANDLED;
+            return -WDG_E_NOTHANDLED;
          break;
 
       /* handle scrolling of the pad */
@@ -268,11 +265,11 @@ static int wdg_scroll_get_msg(struct wdg_object *wo, int key, struct wdg_mouse_e
          
       /* message not handled */
       default:
-         return -WDG_ENOTHANDLED;
+         return -WDG_E_NOTHANDLED;
          break;
    }
   
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /*
@@ -312,7 +309,7 @@ static void wdg_scroll_border(struct wdg_object *wo)
             wmove(ww->win, 0, c - strlen(wo->title) - 3);
             break;
       }
-      wprintw(ww->win, wo->title);
+      wprintw(ww->win, "%s", wo->title);
    }
    
    /* restore the attribute */
