@@ -24,6 +24,7 @@
 #include <ec_gtk3.h>
 #include <ec_capture.h>
 #include <ec_version.h>
+#include <ec_geoip.h>
 
 #include <pcap.h>
 #include <string.h>
@@ -431,8 +432,16 @@ void gtkui_about(GSimpleAction *action, GVariant *value, gpointer data)
    label = gtk_label_new("www.ettercap-project.org");
    gtk_label_set_selectable(GTK_LABEL(label), TRUE);
    gtk_box_pack_start(GTK_BOX(vbox), label, TRUE, TRUE, 0);
-   label = gtk_label_new("#ettercap on FreeNode IRC");
+   label = gtk_label_new("#ettercap on Libera.Chat IRC (irc.libera.chat:6697)");
    gtk_box_pack_start(GTK_BOX(vbox), label, TRUE, TRUE, 0);
+#ifdef HAVE_GEOIP
+   if (EC_GBL_CONF->geoip_support_enable) {
+      label = gtk_label_new("This product includes GeoLite2 Data created by MaxMind,");
+      gtk_box_pack_start(GTK_BOX(vbox), label, TRUE, TRUE, 0);
+      label = gtk_label_new("available from https://www.maxmind.com/.");
+      gtk_box_pack_start(GTK_BOX(vbox), label, TRUE, TRUE, 0);
+   }
+#endif
    label = gtk_label_new(" ");
    gtk_box_pack_start(GTK_BOX(vbox), label, TRUE, TRUE, 30);
    gtk_stack_add_titled(GTK_STACK(stack), vbox, "general", "General");
@@ -1138,7 +1147,7 @@ static void gtkui_build_widgets(GApplication* app, gpointer data)
    gtk_window_set_default_size(GTK_WINDOW(window), width, height);
 
    /* set window icon */
-   path = ICON_DIR "/" ICON_FILE;
+   path = ICON_DIR "/scalable/apps/" ICON_FILE;
    if (g_file_test(path, G_FILE_TEST_EXISTS)) {
       gtk_window_set_icon(GTK_WINDOW(window), gdk_pixbuf_new_from_file(path, NULL));
    }
@@ -1293,7 +1302,7 @@ static void gtkui_build_widgets(GApplication* app, gpointer data)
    menubutton = gtk_button_new();
    gtk_widget_set_tooltip_text(menubutton, "Accept");
    gtk_button_set_image(GTK_BUTTON(menubutton),
-         gtk_image_new_from_icon_name("emblem-ok-symbolic", GTK_ICON_SIZE_BUTTON));
+         gtk_image_new_from_icon_name("object-select-symbolic", GTK_ICON_SIZE_BUTTON));
    gtk_header_bar_pack_end(GTK_HEADER_BAR(header), menubutton);
    g_signal_connect(G_OBJECT(menubutton), "clicked", G_CALLBACK(gtkui_sniff), switcher);
    
