@@ -641,6 +641,10 @@ static void gtkui_connection_detail(void)
    char name[MAX_HOSTNAME_LEN];
    gchar *str, *markup;
    guint row = 0, col = 0;
+#ifdef HAVE_GEOIP
+   char src_country[MAX_GEOIP_STR_LEN];
+   char dst_country[MAX_GEOIP_STR_LEN];
+#endif
 
    DEBUG_MSG("gtk_connection_detail");
 
@@ -759,7 +763,7 @@ static void gtkui_connection_detail(void)
       gtk_widget_set_halign(label, GTK_ALIGN_START);
       gtk_grid_attach(GTK_GRID(grid), label, col, row, 1, 1);
 
-      label = gtk_label_new(geoip_country_by_ip(&c->co->L3_addr1));
+      label = gtk_label_new(geoip_get_by_ip(&c->co->L3_addr1, GEOIP_CNAME, src_country, MAX_GEOIP_STR_LEN));
       gtk_label_set_selectable(GTK_LABEL(label), TRUE);
       gtk_widget_set_halign(label, GTK_ALIGN_START);
       gtk_grid_attach(GTK_GRID(grid), label, col+1, row, 2, 1);
@@ -807,7 +811,7 @@ static void gtkui_connection_detail(void)
       gtk_widget_set_halign(label, GTK_ALIGN_START);
       gtk_grid_attach(GTK_GRID(grid), label, col, row, 1, 1);
 
-      label = gtk_label_new(geoip_country_by_ip(&c->co->L3_addr2));
+      label = gtk_label_new(geoip_get_by_ip(&c->co->L3_addr2, GEOIP_CNAME, dst_country, MAX_GEOIP_STR_LEN));
       gtk_label_set_selectable(GTK_LABEL(label), TRUE);
       gtk_widget_set_halign(label, GTK_ALIGN_START);
       gtk_grid_attach(GTK_GRID(grid), label, col+1, row, 2, 1);
